@@ -455,14 +455,14 @@ perhaps_translate_message (const char *msg)
 /* Internal PAM conversation function. Interfaces between the PAM
  * authentication system and the actual greeter program */
 
-static int 
+static gint 
 gdm_verify_pam_conv (int num_msg, struct pam_message **msg,
 		     struct pam_response **resp,
 		     void *appdata_ptr)
 {
     int replies = 0;
     int i;
-    char *s = NULL;
+    char *s;
     struct pam_response *reply = NULL;
     const void *p;
     const char *login;
@@ -502,10 +502,10 @@ gdm_verify_pam_conv (int num_msg, struct pam_message **msg,
     
     for (replies = 0; replies < num_msg; replies++) {
 	gboolean islogin = FALSE;
-	const char *m = (*msg)[replies].msg;
+	const char *m = msg[replies]->msg;
 	m = perhaps_translate_message (m);
 	
-	switch ((*msg)[replies].msg_style) {
+	switch (msg[replies]->msg_style) {
 	    
 	/* PAM requested textual input with echo on */
 	case PAM_PROMPT_ECHO_ON:
@@ -624,7 +624,7 @@ static struct pam_conv pamc = {
 /* Extra message to give on queries */
 static char *extra_standalone_message = NULL;
 
-static int 
+static gint 
 gdm_verify_standalone_pam_conv (int num_msg, struct pam_message **msg,
 				struct pam_response **resp,
 				void *appdata_ptr)
@@ -645,9 +645,9 @@ gdm_verify_standalone_pam_conv (int num_msg, struct pam_message **msg,
 	memset (reply, 0, sizeof (struct pam_response) * num_msg);
 
 	for (replies = 0; replies < num_msg; replies++) {
-		const char *m = (*msg)[replies].msg;
+		const char *m = msg[replies]->msg;
 		m = perhaps_translate_message (m);
-		switch ((*msg)[replies].msg_style) {
+		switch (msg[replies]->msg_style) {
 
 		case PAM_PROMPT_ECHO_ON:
 			if (extra_standalone_message != NULL)
@@ -852,7 +852,7 @@ authenticate_again:
      * PAM Stacks, in case one display should use a different 
      * authentication mechanism than another display.
      */
-    pam_stack = gdm_get_value_string_per_display ((char *)display, GDM_KEY_PAM_STACK);
+    pam_stack = gdm_get_value_string_per_display (display, GDM_KEY_PAM_STACK);
 
     if ( ! create_pamh (d, pam_stack, login, &pamc, display, &pamerr)) {
 	    if (started_timer)
@@ -1229,7 +1229,7 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, const gchar *display,
      * PAM Stacks, in case one display should use a different 
      * authentication mechanism than another display.
      */
-    pam_stack = gdm_get_value_string_per_display ((char *)display, GDM_KEY_PAM_STACK);
+    pam_stack = gdm_get_value_string_per_display (display, GDM_KEY_PAM_STACK);
     pam_service_name = g_strdup_printf ("%s-autologin", pam_stack);
 
     if ( ! create_pamh (d, pam_service_name, login, &standalone_pamc,
